import { Resource, Timestamp } from '3a-common';
/**
 * Alert interface
 */
export interface Alert extends Resource {
    /**
     * Element id related to the alert
     */
    elementId: string;
    /**
     * Alert description
     */
    description: string;
}
/**
 * Note or annotation made to an element
 */
export interface ElementNote extends Resource {
    /**
     * Note message
     */
    message: string;
    /**
     * Time when note was made
     */
    date: Timestamp;
    /**
     * Note author id
     */
    authorId: string;
    /**
     * Historic event related to the note
     */
    historicEventId: string;
}
/**
 * Trigger that can produce an alert
 */
export interface Trigger extends Resource {
    /**
     * The definite conditions that will fire this trigger to send an alert.
     */
    conditions: TriggerCondition[];
    /**
     * The result that will occur as Alert when trigger is fired (send email, text, etc.)
     */
    result: TriggerResult;
}
/**
 * A single user or person that will receive an alert generated by a trigger
 */
export interface TriggerObserver {
    /**
     * Name of the person or user
     */
    name?: string;
    /**
     * Email to send EMAIL alert
     */
    email?: string;
    /**
     * Phone to send SMS alert
     */
    phone?: string;
    /**
     * The userID if this observer is a known user
     */
    id?: string;
}
/**
 * The possible results types
 */
export declare enum TriggerResultType {
    EMAIL = 0,
    PHONE = 1
}
/**
 * The result that will occur when trigger is fired
 */
export interface TriggerResult {
    /**
     * The type of the result
     */
    type: TriggerResultType;
    /**
     * Observer's list to whom the alert will be sent
     */
    observers: TriggerObserver[];
    /**
     * The message template that will be sent in the alert body
     */
    textTemplate: string;
}
/**
 * A single condition of a trigger
 */
export interface TriggerCondition {
    /**
     * The associated element resourceID (accepts wildcards for multiple element matching)
     */
    elementResourceID: string;
    /**
     * The key inside the element to be evalueated
     */
    key: string;
    /**
     * The relation evaluated to be satisfied
     */
    relation: TriggerConditionRelation;
    /**
     * (Optional) A comparisson value when needed (Equal, NotEqual, StartsWith, Greater, Lesser, Contains)
     */
    value?: any;
    /**
     * Comparison variable type
     */
    type: 'input' | 'number' | 'date';
}
/**
 * The possible condition relations to evaulate a trigger
 */
export declare enum TriggerConditionRelation {
    /**
     * ===
     */
    Equal = 0,
    /**
     * !==
     */
    NotEqual = 1,
    /**
     * !== undefined, !== null
     */
    Exists = 2,
    /**
     * \gval.*\g
     */
    StartsWith = 3,
    /**
     * >
     */
    Greater = 4,
    /**
     * <
     */
    Lesser = 5,
    /**
     * \g.*val.*\
     */
    Contains = 6,
    /**
     * lastValue !== currentValue
     */
    Changed = 7
}
/**
 * Label-value pair used to show comparison relation on add/edit trigger modal
 */
export declare const CONDITION_RELATION_OPTIONS: {
    label: string;
    value: TriggerConditionRelation;
}[];
/**
 * Object used to decide which relations must be shown according the condition variable type
 */
export declare const AVAILABLE_RELATIONS_BY_TYPE: {
    input: TriggerConditionRelation[];
    number: TriggerConditionRelation[];
    date: TriggerConditionRelation[];
};
